@@ -759,21 +759,24 @@ class DiceBot(Bot):
                     return "Bad value: %s" % e
                 return hande(heaven, earth, passing_grade)
         if _generic.search(args):
-            num, size = _generic.search(args).groups()
-            if num == '':
-                num = 1
-            if size == 'F' or size == 'f':
+            ret = []
+            for pair in _generic.findall(args):
+                num, size = pair
+                if num == '':
+                    num = 1
+                if size == 'F' or size == 'f':
+                    try:
+                        num = int(num)
+                    except ValueError, e:
+                        return "Bad number: %s" % e
+                    ret.append(fudge(num))
                 try:
                     num = int(num)
+                    size = int(size)
                 except ValueError, e:
-                    return "Bad number: %s" % e
-                return fudge(num)
-            try:
-                num = int(num)
-                size = int(size)
-            except ValueError, e:
-                return "Bad size: %s" % e
-            return generic(num, size)
+                    return "Bad size: %s" % e
+                ret.append(generic(num, size))
+            return '; '.join(ret)
         if _rick.search(args):
             time.sleep(rand(1, 3))
             return "http://is.gd/czLKl"
@@ -872,6 +875,8 @@ class DiceBot(Bot):
             return "The other half is bullets."
         if re.search(MEMES[15], args, re.I):
             return "-ang Clan ain't nuthin' ta fuck wit'!"
+        if re.search(MEMES[16], args, re.I):
+            return "Everyone? http://tinyurl.com/3cmbtw"
     def sound_effects(self, msg):
         args = msg.getBody()
         if re.search(SOUND_EFFECTS[0], args, re.I):
@@ -897,6 +902,7 @@ MEMES = [r'(spartans(!|,)\s+what is your profession\?)',
         r'(when i move[,:]? you move)',
         r'((and )?knowing is half the battle\.?)',
         r'(w00(t|7))',
+        r'(.*everyone.)',
         ]
 
 SOUND_EFFECTS = [r'\*rimshot\*',
